@@ -151,6 +151,8 @@ impl FileTypeDescription for FileType {
                 FileType::Matroska => Some(4),
                 FileType::Wasm => Some(4),
                 FileType::Class => Some(4),
+                FileType::Tasty => Some(4),
+                FileType::Mach => Some(4),
                 FileType::Elf => Some(4),
                 FileType::Wav => Some(12),
                 FileType::Avi => Some(12),
@@ -158,6 +160,12 @@ impl FileTypeDescription for FileType {
                 FileType::Tiff => Some(4),
                 FileType::Sqlite3 => Some(16),
                 FileType::Ico => Some(4),
+                FileType::Dalvik => Some(8),
+                FileType::Pdf => Some(5),
+                FileType::DosMzExecutable | FileType::DosZmExecutable => Some(2),
+                FileType::Xcf => Some(10),
+                FileType::Gif => Some(4),
+                FileType::Bmp => Some(2),
             }
         } else {
             match self {
