@@ -45,7 +45,9 @@
 //! - Flac
 //! - Matroska (mkv, mka, mks, mk3d, webm)
 //! - Wasm
-//! - Java Class/Mach-O Fat Binary
+//! - Java Class
+//! - Scala Tasty
+//! - Mach-O
 //! - Elf (Executable and Linkable Format)
 //! - Wav
 //! - Avi
@@ -53,6 +55,13 @@
 //! - Tiff
 //! - Sqlite3 (`.db`)
 //! - Ico
+//! - Dalvik
+//! - Pdf
+//! - Exe/Dll
+//! - Gif
+//! - Xcf
+//! - Scala Tasty
+//! - Bmp
 //!
 //! ## First Step
 //!
@@ -131,7 +140,7 @@ pub mod matcher;
 pub mod types;
 
 /// Stores information about a specific [FileType] match result.
-#[derive(Debug, Clone, Eq, PartialEq)]
+#[derive(Debug, Clone, Eq, PartialEq, Hash)]
 pub struct FileTypeMatch {
     /// [FileType] that matched
     file_type: FileType,
@@ -471,6 +480,7 @@ mod tests {
     extern crate test;
     use crate::types::FileType;
     use crate::{detect, detect_at_end, FileTypeMatch, FileTypeMatches};
+    use std::collections::HashSet;
     use std::fs::OpenOptions;
     use std::io::{BufReader, Error, ErrorKind};
     use std::path::Path;
@@ -488,7 +498,13 @@ mod tests {
 
     #[test]
     fn test_rar_sfx_detect() {
-        test_detect_match("files/hello-world.exe", FileType::Rar5);
+        test_detect_match_n(
+            "files/hello-world.exe",
+            vec![
+                FileTypeMatch::new(FileType::Rar5, true),
+                FileTypeMatch::new(FileType::DosMzExecutable, false),
+            ],
+        );
     }
 
     #[test]
@@ -528,7 +544,7 @@ mod tests {
 
     #[test]
     fn test_flac_detect() {
-        test_detect_match("files/test-flac.flac", FileType::Flac);
+        test_detect_match_maybe("files/test-flac.flac", FileType::Flac);
     }
 
     #[test]
@@ -574,7 +590,12 @@ mod tests {
     // False positive - how to avoid?
     #[test]
     fn test_flac_txt_detect() {
-        test_detect_match("files/test-flac.txt", FileType::Flac);
+        test_detect_match_maybe("files/test-flac.txt", FileType::Flac);
+    }
+
+    #[test]
+    fn test_pdf_detect() {
+        test_detect_match_maybe("files/rust-logo.pdf", FileType::Pdf);
     }
 
     #[test]
@@ -587,6 +608,26 @@ mod tests {
         test_detect_match("files/rust-logo.ico", FileType::Ico);
     }
 
+    #[test]
+    fn test_tasty_detect() {
+        test_detect_match("files/test-tasty.tasty", FileType::Tasty);
+    }
+
+    #[test]
+    fn test_xcf_detect() {
+        test_detect_match_maybe("files/rust-logo.xcf", FileType::Xcf);
+    }
+
+    #[test]
+    fn test_gif_detect() {
+        test_detect_match_maybe("files/rust-logo.gif", FileType::Gif);
+    }
+
+    #[test]
+    fn test_bmp_detect() {
+        test_detect_match_maybe("files/rust-logo.bmp", FileType::Bmp);
+    }
+
     #[test]
     fn test_txt_no_match() {
         test_detect_no_match("files/text");
@@ -634,6 +675,48 @@ mod tests {
         assert_eq!(detect, expected);
     }
 
+    fn test_detect_match_n<P>(path: P, file_type_match: Vec<FileTypeMatch>) -> ()
+    where
+        P: AsRef<Path>,
+    {
+        let detect = test_detect(path).map_err(|e| e.kind());
+        assert_eq!(true, detect.is_ok());
+        let detect_option = detect.unwrap();
+        assert_eq!(true, detect_option.is_some());
+
+        let types: HashSet<FileType> = file_type_match
+            .iter()
+            .map(|v| v.file_type.clone())
+            .collect();
+
+        let detected = detect_option.unwrap();
+        let likely_types: HashSet<FileType> =
+            detected.likely_to_be.iter().map(|v| v.clone()).collect();
+
+        assert_eq!(types, likely_types);
+
+        let should_match: HashSet<FileTypeMatch> =
+            file_type_match.iter().map(|v| v.clone()).collect();
+
+        let matches: HashSet<FileTypeMatch> =
+            detected.all_matches.iter().map(|v| v.clone()).collect();
+
+        assert_eq!(should_match, matches);
+    }
+
+    fn test_detect_match_maybe<P>(path: P, file_type: FileType) -> ()
+    where
+        P: AsRef<Path>,
+    {
+        let detect = test_detect(path).map_err(|e| e.kind());
+        let expected: Result<Option<FileTypeMatches>, ErrorKind> = Ok(Some(FileTypeMatches::new(
+            vec![file_type],
+            vec![FileTypeMatch::new(file_type, false)],
+        )));
+
+        assert_eq!(detect, expected);
+    }
+
     fn test_detect_no_match<P>(path: P) -> ()
     where
         P: AsRef<Path>,
