@@ -132,6 +132,8 @@ impl FileTypeMatcher for FileType {
             FileType::Matroska => matroska_test(&relative_position, step, &bytes),
             FileType::Wasm => wasm_test(&relative_position, step, &bytes),
             FileType::Class => class_test(&relative_position, step, &bytes),
+            FileType::Tasty => tasty_test(&relative_position, step, &bytes),
+            FileType::Mach => mach_test(&relative_position, step, &bytes),
             FileType::Elf => elf_test(&relative_position, step, &bytes),
             FileType::Wav => wav_test(&relative_position, step, &bytes),
             FileType::Avi => avi_test(&relative_position, step, &bytes),
@@ -139,6 +141,13 @@ impl FileTypeMatcher for FileType {
             FileType::Tiff => tiff_test(&relative_position, step, &bytes),
             FileType::Sqlite3 => sqlite3_test(&relative_position, step, &bytes),
             FileType::Ico => ico_test(&relative_position, step, &bytes),
+            FileType::Dalvik => dalvik_test(&relative_position, step, &bytes),
+            FileType::Pdf => pdf_test(&relative_position, step, &bytes),
+            FileType::DosMzExecutable => dos_mz_test(&relative_position, step, &bytes),
+            FileType::DosZmExecutable => dos_zm_test(&relative_position, step, &bytes),
+            FileType::Xcf => xcf_test(&relative_position, step, &bytes),
+            FileType::Gif => gif_test(&relative_position, step, &bytes),
+            FileType::Bmp => bmp_test(&relative_position, step, &bytes),
         }
     }
 }
@@ -328,7 +337,7 @@ fn webp_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) ->
 const FLAC_SIGNATURE: [u8; 4] = [0x66, 0x4C, 0x61, 0x43];
 fn flac_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
     if *relative_position == RelativePosition::Start && *step == Step::Small {
-        return slice_test(&bytes, &FLAC_SIGNATURE);
+        return slice_test_maybe(&bytes, &FLAC_SIGNATURE);
     }
 
     return TestResult::NotMatched;
@@ -361,6 +370,24 @@ fn class_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -
     return TestResult::NotMatched;
 }
 
+const TASTY_SIGNATURE: [u8; 4] = [0x5C, 0xA1, 0xAB, 0x1F];
+fn tasty_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &TASTY_SIGNATURE);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const MACH_SIGNATURE: [u8; 4] = [0xCF, 0xFA, 0xED, 0xFE];
+fn mach_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &MACH_SIGNATURE);
+    }
+
+    return TestResult::NotMatched;
+}
+
 const ELF_SIGNATURE: [u8; 4] = [0x7F, 0x45, 0x4C, 0x46];
 fn elf_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
     if *relative_position == RelativePosition::Start && *step == Step::Small {
@@ -440,6 +467,69 @@ fn ico_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) ->
     return TestResult::NotMatched;
 }
 
+const DALVIK_SIGNATURE_1: [u8; 8] = [0x64, 0x65, 0x78, 0x0A, 0x30, 0x33, 0x35, 0x00];
+fn dalvik_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &DALVIK_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const PDF_SIGNATURE_1: [u8; 5] = [0x25, 0x50, 0x44, 0x46, 0x2D];
+fn pdf_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test_maybe(&bytes, &PDF_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const DOS_MZ_SIGNATURE_1: [u8; 2] = [0x4D, 0x5A];
+fn dos_mz_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test_maybe(&bytes, &DOS_MZ_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const DOS_ZM_SIGNATURE_1: [u8; 2] = [0x5A, 0x4D];
+fn dos_zm_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test(&bytes, &DOS_ZM_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const XCF_SIGNATURE_1: [u8; 10] = [0x67, 0x69, 0x6D, 0x70, 0x20, 0x78, 0x63, 0x66, 0x20, 0x76];
+fn xcf_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test_maybe(&bytes, &XCF_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const GIF_SIGNATURE_1: [u8; 4] = [0x47, 0x49, 0x46, 0x38];
+fn gif_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test_maybe(&bytes, &GIF_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
+const BMP_SIGNATURE_1: [u8; 2] = [0x42, 0x4d];
+fn bmp_test(relative_position: &RelativePosition, step: &Step, bytes: &[u8]) -> TestResult {
+    if *relative_position == RelativePosition::Start && *step == Step::Small {
+        return slice_test_maybe(&bytes, &BMP_SIGNATURE_1);
+    }
+
+    return TestResult::NotMatched;
+}
+
 fn slice_test(bytes: &[u8], matching: &[u8]) -> TestResult {
     if bytes.len() >= matching.len() {
         if &bytes[..matching.len()] == matching {
@@ -449,3 +539,13 @@ fn slice_test(bytes: &[u8], matching: &[u8]) -> TestResult {
 
     return TestResult::NotMatched;
 }
+
+fn slice_test_maybe(bytes: &[u8], matching: &[u8]) -> TestResult {
+    if bytes.len() >= matching.len() {
+        if &bytes[..matching.len()] == matching {
+            return TestResult::Maybe;
+        }
+    }
+
+    return TestResult::NotMatched;
+}
