@@ -25,7 +25,7 @@
 //! File Type module
 
 /// FileType
-#[derive(Debug, Copy, Clone, Eq, PartialEq)]
+#[derive(Debug, Copy, Clone, Eq, PartialEq, Hash)]
 pub enum FileType {
     /// Zip File format, this includes:
     /// - jar
@@ -36,7 +36,7 @@ pub enum FileType {
     Zip,
     Rar,
     Rar5,
-    /// Tar archive, regardless the compression
+    /// Tar archive (regardless the compression)
     Tar,
     Png,
     Jpg,
@@ -57,9 +57,15 @@ pub enum FileType {
     Matroska,
     /// WebAssembly
     Wasm,
-    /// Java class and Mach-O Fat Binary
+    /// Java class
     Class,
+    /// Scala Tasty
+    Tasty,
+    /// Mach-O (untested)
+    Mach,
     /// Executable and Linkable Format
+    /// - `.so`
+    /// - `*nix executable`
     Elf,
     /// Waveform Audio File Format
     Wav,
@@ -78,11 +84,28 @@ pub enum FileType {
     /// SQLite 3 Database
     Sqlite3,
     Ico,
+    /// Dalvik (untested)
+    Dalvik,
+    /// PDF Document
+    Pdf,
+    /// DOS MZ Executable
+    /// - `.exe`
+    /// - `.dll`
+    DosMzExecutable,
+    /// DOS ZM Executable
+    /// - `.exe`
+    DosZmExecutable,
+    /// Gimp XCF
+    Xcf,
+    /// Gif
+    Gif,
+    /// Bitmap
+    Bmp,
 }
 
 impl FileType {
     /// Gets all variants of [FileType]
-    pub fn variants() -> [FileType; 22] {
+    pub fn variants() -> [FileType; 31] {
         [
             FileType::Zip,
             FileType::Rar,
@@ -99,6 +122,8 @@ impl FileType {
             FileType::Matroska,
             FileType::Wasm,
             FileType::Class,
+            FileType::Tasty,
+            FileType::Mach,
             FileType::Elf,
             FileType::Wav,
             FileType::Avi,
@@ -106,6 +131,13 @@ impl FileType {
             FileType::Tiff,
             FileType::Sqlite3,
             FileType::Ico,
+            FileType::Dalvik,
+            FileType::Pdf,
+            FileType::DosMzExecutable,
+            FileType::DosZmExecutable,
+            FileType::Xcf,
+            FileType::Gif,
+            FileType::Bmp,
         ]
     }
 
@@ -126,6 +158,8 @@ impl FileType {
             FileType::Matroska => FileRootType::Matroska,
             FileType::Wasm => FileRootType::Wasm,
             FileType::Class => FileRootType::Class,
+            FileType::Tasty => FileRootType::Tasty,
+            FileType::Mach => FileRootType::Mach,
             FileType::Elf => FileRootType::Elf,
             FileType::Wav => FileRootType::Wav,
             FileType::Avi => FileRootType::Avi,
@@ -133,6 +167,13 @@ impl FileType {
             FileType::Tiff => FileRootType::Tiff,
             FileType::Sqlite3 => FileRootType::Sqlite3,
             FileType::Ico => FileRootType::Ico,
+            FileType::Dalvik => FileRootType::Dalvik,
+            FileType::Pdf => FileRootType::Pdf,
+            FileType::DosMzExecutable => FileRootType::DosExecutable,
+            FileType::DosZmExecutable => FileRootType::DosExecutable,
+            FileType::Xcf => FileRootType::Xcf,
+            FileType::Gif => FileRootType::Gif,
+            FileType::Bmp => FileRootType::Bmp,
         }
     }
 }
@@ -153,6 +194,8 @@ pub enum FileRootType {
     Matroska,
     Wasm,
     Class,
+    Tasty,
+    Mach,
     Elf,
     Wav,
     Avi,
@@ -160,4 +203,10 @@ pub enum FileRootType {
     Tiff,
     Sqlite3,
     Ico,
+    Dalvik,
+    Pdf,
+    DosExecutable,
+    Xcf,
+    Gif,
+    Bmp,
 }
